/**
 * 患者教育活动-添加
 * @author 韩慧
 * @date 2019.12.11
 */
define(['plugin/validate', 'moment'], function (validator, moment) {
    var container = null,
        navbarInnerContainer = null,
        detailData = null,
        defaultSelectArrValue = [];
    return {
        init: function (page) {
            if (page.from == 'right') {
                container = $$(page.container);
                navbarInnerContainer = $$(page.navbarInnerContainer).length ? $$(page.navbarInnerContainer) : container.find('.navbar .navbar-inner');
                detailData = page.query.detailData;
                showData();
            }
        }
    };
    // 数据展示
    function showData() {
        $$.each(detailData, function (key, value) {
            container.find('[name="' + key + '"]').val(value);
        });
        detailData.selectOptions = [];
        var newArr = detailData.form.split(',');
        for (var i = 0; i < newArr.length; i++) {
            var tex = {
                'text': newArr[i]
            }
            detailData.selectOptions.push(tex);
        }
        selecteventsCallback(detailData);
        // 事件绑定
        bindEvent();
    };
    // 点击事件
    function bindEvent() {
        // 活动形式
        container.find('.form').on('click', function () {
            defaultSelectArrValue = [];
            var selectArr = $$('.formSelect .content-block-inner .chip');
            for (var i = 0; i < selectArr.length; i++) {
                var tax = {
                    'id': selectArr[i].id,
                    'text': $$(selectArr[i]).find('.chip-label').text()
                }
                defaultSelectArrValue.push(tax);
            }
            getOptionsData('活动形式');
        });
        // 计划开始结束时间
        var startTime = container.find('[name="startTime"]'),
            endTime = container.find('[name="endTime"]');
        if (detailData.sprPlanDetailId || detailData.sprCompleteDetailId) {
            // 给开始结束时间添加默认值，结束时间
            common.calendarLimitPicker(startTime, detailData.calendarBeginDate, detailData.calendarendTime);
            common.calendarLimitPicker(endTime, detailData.calendarBeginDate, detailData.calendarendTime);
        } else {
            // 给开始结束时间添加默认值，当天
            common.calendarPicker(startTime);
            common.calendarPicker(endTime);
        }
        // 保存 
        navbarInnerContainer.find('.btn-submit').click(function () {
            validator.validateForm();
        });
        // 表单验证 
        var validator = new FormValidator('form-market-patient-education-edit', [{
            name: 'name',
            display: '活动名称',
            rules: 'required'
        }, {
            name: 'entrustingPartyPerson',
            display: '委托方参与人员',
            rules: 'required'
        }, {
            name: 'diseaseDomain',
            display: '疾病领域',
            rules: 'required'
        }, {
            name: 'patientEducationObject',
            display: '患教对象',
            rules: 'required'
        }, {
            name: 'city',
            display: '活动城市',
            rules: 'required'
        }, {
            name: 'place',
            display: '活动地点',
            rules: 'required'
        }, {
            name: 'trainSpeaker',
            display: '培训主讲',
            rules: 'required'
        }, {
            name: 'participantsNumber',
            display: '参与人数',
            rules: 'required|numeric',
        }, {
            name: 'startTime',
            display: '活动开始日期',
            rules: 'required'
        }, {
            name: 'endTime',
            display: '活动结束日期',
            rules: 'required'
        }, {
            name: 'content',
            display: '活动内容',
            rules: 'required'
        }, {
            name: 'objective',
            display: '活动目的',
            rules: 'required'
        }], function (errors, event) {
            if (errors.length > 0) {
                $$.each(errors, function (index, value) {
                    common.notification('提示', value.message, 'warning');
                });
            } else {
                if ($$('.formSelect .content-block-inner .chip').length > 0) {
                    // 验证结束时间是否早于开始时间
                    if (container.find('[name="endTime"]').val() >= container.find('[name="startTime"]').val()) {
                        navbarInnerContainer.find('.btn-submit').addClass('disabled');
                        saveData();
                    } else {
                        common.notification('提示', '结束时间不能早于开始时间', 'warning');
                    }
                } else {
                    common.notification('提示', '请选择活动形式', 'warning');
                }
            }
        });
    }
    //获取活动形式选项集数据
    function getOptionsData() {
        // 加载loading
        app.showIndicator();
        var values = { 'OtherId': 4 };
        var param = {
            ajaxUrl: 'api/services/app/dictionary/GetExtLogoLibForSelect2',
            ajaxMethod: 'post',
            ajaxValues: values,
            ajaxCallback: getOptionsDataCallback,
            ajaxAgainEvt: getOptionsData,
            ajaxText: '获取活动形式'
        }
        common.ajaxMethod(param);
    }
    function getOptionsDataCallback(ret) {
        var optionData = {
            'data': []
        },
            eventData = ret.result;
        for (var i = 0; i < eventData.length; i++) {
            optionData.data[i] = {};
            optionData.data[i].id = eventData[i].id;
            optionData.data[i].name = eventData[i].text //名称
        }
        require(['plugin/component/checkbox-common-options'], function (events) {
            events.init(optionData, defaultSelectArrValue, selecteventsCallback);
        });
    }
    //活动形式选择回调
    function selecteventsCallback(data) {
        if (!data.selectOptions || data.selectOptions.length == 0) {
            container.find('.formSelect .content-block-inner').html('<span class="color-gray">还没有选择活动形式</span>');
            return;
        }
        //编译模板数据
        var template = container.find('.formSelect .tmp-chip').html();
        var compiledTemplate = Template7.compile(template);
        var html = compiledTemplate(data);
        container.find('.formSelect .content-block-inner').html(html);
        //删除活动形式
        container.find('.formSelect .chip-delete').off('click', chipDeleteEvt);
        container.find('.formSelect .chip-delete').on('click', chipDeleteEvt);
    }
    function chipDeleteEvt() {
        var that = $$(this);
        app.confirm('确定删除此活动形式？', function () {
            that.parents($$('.chip')).remove();
            var length = container.find('.formSelect .content-block-inner .chip').length;
            if (!length) {
                container.find('.formSelect .content-block-inner').html('<span class="color-gray">还没有选择活动形式</span>');
            }
        });
    }
    // 保存
    function saveData() {
        app.showIndicator();
        var values = app.formToJSON('form[name="form-market-patient-education-edit"]');
        // 活动形式
        var form = '';
        var selectArr = $$('.formSelect .content-block-inner .chip');
        for (var i = 0; i < selectArr.length; i++) {
            form += $$(selectArr[i]).text();
            if (i < selectArr.length - 1) {
                form += ',';
            }
        }
        values.form = form;
        values.id = detailData.id;
        values.status = detailData.status;
        values.sprReportId = detailData.sprReportId;
        values.sprPlanDetailId = detailData.sprPlanDetailId;
        // app端
        values.isApp = true;
        var param = {
            ajaxUrl: 'api/services/app/reportPatientEducationActivity/CreateOrUpdateReportPatientEducationActivity',
            ajaxMethod: 'post',
            ajaxValues: values,
            ajaxCallback: saveDataCallback,
            ajaxAgainEvt: saveData,
            ajaxText: '编辑患者教育活动'
        }
        common.ajaxMethod(param);
    }
    function saveDataCallback(ret) {
        navbarInnerContainer.find('.btn-submit').removeClass('disabled');
        if (ret.result.status == 'y') {
            common.notification('恭喜', '保存成功', 'success');
            // 更新列表数据页面
            $$(document).trigger('after-list-update');
            var currentView = app.getCurrentView();
            currentView.router.back();
        } else {
            //弹出提示,这里比较特殊返回信息里有是否是Y的判断,这里单独判断下
            app.modal({
                title: '操作失败',
                text: '<i class="icon icon-error"></i>' + '<p class="decription">' + ret.result.msg + '</p>',
                buttons: [{
                    text: '知道了'
                }]
            });
        }
    }
});