/**
 * 赞助学术会议-添加
 * @author 韩慧
 * @date 2019.12.11
 */
define(['plugin/validate', 'moment'], function (validator, moment) {
    var container = null,
        navbarInnerContainer = null,
        sprPlanDetailId = '',
        taskData = null,
        conferenceagendas = [],
        conferencenums = [];
    return {
        init: function (page) {
            if (page.from == 'right') {
                container = $$(page.container);
                navbarInnerContainer = $$(page.navbarInnerContainer).length ? $$(page.navbarInnerContainer) : container.find('.navbar .navbar-inner');
                taskData = page.query.taskData;
                sprPlanDetailId = taskData ? taskData.sprPlanDetailId : '';
                bindEvent();
            }
        }
    };
    // 点击事件
    function bindEvent() {
        // 计划开始结束时间
        var startdate = container.find('[name="startdate"]'),
            enddate = container.find('[name="enddate"]');
        if (taskData) {
            // 给开始结束时间添加默认值，结束时间
            startdate.val(moment(taskData.calendarEndDate).format('YYYY-MM-DD'));
            enddate.val(moment(taskData.calendarEndDate).format('YYYY-MM-DD'));
            common.calendarLimitPicker(startdate, taskData.calendarBeginDate, taskData.calendarEndDate);
            common.calendarLimitPicker(enddate, taskData.calendarBeginDate, taskData.calendarEndDate);
        } else {
            // 给开始结束时间添加默认值，当天
            startdate.val(moment(new Date()).format('YYYY-MM-DD'));
            enddate.val(moment(new Date()).format('YYYY-MM-DD'));
            common.calendarPicker(startdate);
            common.calendarPicker(enddate);
        }
        // 添加议程
        container.find('.btn-add-conferenceagendas').on('click', function () {
            openPopup('添加议程');
        });
        // 添加成员
        container.find('.btn-add-conferencenums').on('click', function () {
            openPopup('添加成员');
        });
        // 保存 
        navbarInnerContainer.find('.btn-submit').click(function () {
            validator.validateForm();
        });
        // 表单验证 
        var validator = new FormValidator('form-market-spread-sponsor-add', [{
            name: 'conferencename',
            display: '会议名称',
            rules: 'required',
        }, {
            name: 'sponsor',
            display: '主办方',
            rules: 'required',
        }, {
            name: 'sponsornature',
            display: '赞助性质',
            rules: 'required',
        }, {
            name: 'sponsorPurpose',
            display: '赞助目的',
            rules: 'required',
        }, {
            name: 'conferenceplace',
            display: '会议地点',
            rules: 'required',
        }, {
            name: 'invitenum',
            display: '我司赞助人数',
            rules: 'required|numeric',
        }, {
            name: 'attendees',
            display: '与会人数',
            rules: 'required|numeric',
        }, {
            name: 'ourAttendancenum',
            display: '我司与会人数',
            rules: 'numeric',
        }, {
            name: 'startdate',
            display: '会议开始日期',
            rules: 'required',
        }, {
            name: 'enddate',
            display: '会议结束日期',
            rules: 'required',
        }, {
            name: 'serviceMember',
            display: '服务成员',
            rules: 'required',
        }, {
            name: 'purpose',
            display: '会议目的',
            rules: 'required',
        }, {
        }], function (errors, event) {
            if (errors.length > 0) {
                $$.each(errors, function (index, value) {
                    common.notification('提示', value.message, 'warning');
                });
            } else {
                // 验证结束时间是否早于开始时间
                if (container.find('[name="enddate"]').val() >= container.find('[name="startdate"]').val()) {
                    navbarInnerContainer.find('.btn-submit').addClass('disabled');
                    saveData();
                } else {
                    common.notification('提示', '结束时间不能早于开始时间', 'warning');
                }
            }
        });
    }
    // 打开popup
    function openPopup(type) {
        var popupHTML = '<div class="popup popup-metting"><div class="view navbar-fixed"><div class="pages"><div data-page="popup-metting" class="page"><div class="navbar"><div class="navbar-inner"><div class="left"><a href="#" class="close-popup link"><i class="icon icon-close"></i><span>关闭</span></a></div><div class="center">' + type + '</div><div class="right"><a href="javascript:void(0);" class="link btn-submit"><i class="icon icon-submit"></i></a></div></div></div><div class="page-content">';
        // 判断打开哪个popup
        if (type == '添加议程') {
            popupHTML += '<form name="form-add-conferenceagendas"><div class="list-block"><ul><li class="item-content"><div class="item-inner"><div class="item-title label">开始时间</div><div class="item-input"><input type="text" name="startconfriencrTime" placeholder="必填" readonly="true"></div></div></li><li class="item-content"><div class="item-inner"><div class="item-title label">结束时间</div><div class="item-input"><input type="text" name="endconfriencrTime" placeholder="必填" readonly="true"></div></div></li><li class="item-content"><div class="item-inner"><div class="item-title label">议程主题</div><div class="item-input"><input type="text" name="theme" placeholder="请填写议程主题"></div></div></li><li class="item-content"><div class="item-inner"><div class="item-title label">议程人员</div><div class="item-input"><input type="text" name="people" placeholder="必填"></div></div></li></ul></div></form>';
        } else if (type == '添加成员') {
            popupHTML += '<form name="form-add-conferencenums"><div class="list-block"><ul><li class="item-content"><div class="item-inner"><div class="item-title label">人员名称</div><div class="item-input"><input type="text" name="peopleName" placeholder="必填"></div></div></li><li class="item-content"><div class="item-inner"><div class="item-title label">单位名称</div><div class="item-input"><input type="text" name="uniteName" placeholder="请填写单位名称"></div></div></li><li class="item-content"><div class="item-inner"><div class="item-title label">部门名称</div><div class="item-input"><input type="text" name="departmentName" placeholder="请填写部门名称"></div></div></li><li class="item-content"><div class="item-inner"><div class="item-title label">手机号</div><div class="item-input"><input type="text" name="tel" placeholder="请填写手机号"></div></div></li><li class="item-content"><div class="item-inner"><div class="item-title label">参与角色</div><div class="item-input"><input type="text" name="participatoryRole" placeholder="请填写参与角色"></div></div></li></ul></div></form>';
        }
        popupHTML += '</div></div></div></div></div>';
        app.popup(popupHTML);
        $$('.popup-metting').on('opened', function () {
            containerPopup = $$('.popup-metting');
            navbarInnerContainerPopup = containerPopup.find('.navbar');
            bindEventPopup(type);
        });
    }
    function bindEventPopup(type) {
        // 计划开始结束时间
        var startconfriencrTime = containerPopup.find('[name="startconfriencrTime"]'),
            endconfriencrTime = containerPopup.find('[name="endconfriencrTime"]');
        // 给开始结束时间添加默认值，当天
        var defaultDate = moment(new Date()).format('YYYY-MM-DD HH:mm');
        startconfriencrTime.val(defaultDate);
        endconfriencrTime.val(defaultDate);
        // 添加日期选择器
        common.dateTimePicker(startconfriencrTime);
        common.dateTimePicker(endconfriencrTime);
        // 保存 
        navbarInnerContainerPopup.find('.btn-submit').on('click', function () {
            if (type == '添加议程') {
                validatorPopupconferenceagendas.validateForm();
            } else if (type == '添加成员') {
                validatorPopupconferencenums.validateForm();
            }
        });
        // 表单验证   conferenceagendas
        var validatorPopupconferenceagendas = new FormValidator('form-add-conferenceagendas', [{
            name: 'startconfriencrTime',
            display: '开始时间',
            rules: 'required'
        }, {
            name: 'endconfriencrTime',
            display: '结束时间',
            rules: 'required'
        }, {
            name: 'people',
            display: '议程人员',
            rules: 'required'
        }], function (errors, event) {
            if (errors.length > 0) {
                $$.each(errors, function (index, value) {
                    common.notification('提示', value.message, 'warning');
                });
            } else {
                // 验证结束时间是否早于开始时间
                if (containerPopup.find('[name="endconfriencrTime"]').val() >= containerPopup.find('[name="startconfriencrTime"]').val()) {
                    navbarInnerContainerPopup.find('.btn-submit').addClass('disabled');
                    clickEventPopup(type);
                } else {
                    common.notification('提示', '结束时间不能早于开始时间', 'warning');
                }
            }
        });
        // 表单验证   conferencenums
        var validatorPopupconferencenums = new FormValidator('form-add-conferencenums', [{
            name: 'peopleName',
            display: '人员名称',
            rules: 'required'
        }, {
            name: 'tel',
            display: '手机号',
            rules: 'valid_phone'
        }], function (errors, event) {
            if (errors.length > 0) {
                $$.each(errors, function (index, value) {
                    common.notification('提示', value.message, 'warning');
                });
            } else {
                navbarInnerContainerPopup.find('.btn-submit').addClass('disabled');
                clickEventPopup(type);
            }
        });
    }
    function clickEventPopup(type) {
        if (type == '添加议程') {
            var dataJson = {
                status: 'add',
                conferenceOrder: containerPopup.find('[name="conferenceOrder"]').val(),// 议程顺序  
                confriencrTime: containerPopup.find('[name="startconfriencrTime"]').val() + ' ~ ' + containerPopup.find('[name="endconfriencrTime"]').val(),// 时间段  
                people: containerPopup.find('[name="people"]').val(),// 议程人员  
                theme: containerPopup.find('[name="theme"]').val()// 议程主题
            };
            conferenceagendas.push(dataJson);
            $$.each(conferenceagendas, function (index, item) {
                item.conferenceOrder = index + 1;
            });
            var ret = {
                'data': conferenceagendas
            }
            // 编译模板
            var template = container.find('.tmp-conferenceagendas-list').html();
            var compiledTemplate = Template7.compile(template);
            var html = compiledTemplate(ret);
            container.find('.conferenceagendas-list').html('<ul>' + html + '</ul>');
        } else if (type == '添加成员') {
            var dataJson = {
                status: 'add',
                uniteName: containerPopup.find('[name="uniteName"]').val(), // 单位名称
                departmentName: containerPopup.find('[name="departmentName"]').val(), // 部门名称
                peopleName: containerPopup.find('[name="peopleName"]').val(), // 人员名称
                tel: containerPopup.find('[name="tel"]').val(), // 手机号码
                participatoryRole: containerPopup.find('[name="participatoryRole"]').val() // 参与角色
            };
            conferencenums.push(dataJson);
            var ret = {
                'data': conferencenums
            }
            // 编译模板
            var template = container.find('.tmp-conferencenums-list').html();
            var compiledTemplate = Template7.compile(template);
            var html = compiledTemplate(ret);
            container.find('.conferencenums-list').html('<ul>' + html + '</ul>');
        }
        //删除先解除绑定，再绑定，防止重复加载
        container.find('.swipeout').off('deleted', delEvent);
        container.find('.swipeout').on('deleted', delEvent);
        // 关闭popup
        app.closeModal('.popup-metting');
    }
    // 调用删除方法
    function delEvent() {
        var type = $$(this).attr('data-type'),
            conferenceOrder = $$(this).attr('data-conferenceOrder'),
            peopleName = $$(this).attr('data-peopleName'),
            dataName = $$(this).attr('data-name');
        if (type == 'conferenceagendas') {
            // 议程
            // 删除数组中对应的数据
            for (var i = 0; i < conferenceagendas.length; i++) {
                if (conferenceagendas[i].conferenceOrder == conferenceOrder) {
                    conferenceagendas.splice(i, 1); //删除下标为i的元素
                }
            }
            $$.each(conferenceagendas, function (index, item) {
                item.conferenceOrder = index + 1;
            });
            var ret = {
                'data': conferenceagendas
            }
            // 编译模板
            var template = container.find('.tmp-conferenceagendas-list').html();
            var compiledTemplate = Template7.compile(template);
            var html = compiledTemplate(ret);
            container.find('.conferenceagendas-list').html('<ul>' + html + '</ul>');
        } else if (type == 'conferencenums') {
            // 添加成员
            // 删除数组中对应的数据
            for (var i = 0; i < conferencenums.length; i++) {
                if (conferencenums[i].peopleName == peopleName) {
                    conferencenums.splice(i, 1); //删除下标为i的元素
                }
            }
            var ret = {
                'data': conferencenums
            }
            // 编译模板
            var template = container.find('.tmp-conferencenums-list').html();
            var compiledTemplate = Template7.compile(template);
            var html = compiledTemplate(ret);
            container.find('.conferencenums-list').html('<ul>' + html + '</ul>');
        }
        //删除先解除绑定，再绑定，防止重复加载
        container.find('.swipeout').off('deleted', delEvent);
        container.find('.swipeout').on('deleted', delEvent);
    }
    // 保存
    function saveData() {
        app.showIndicator();
        var values = app.formToJSON('form[name="form-market-spread-sponsor-add"]');
        values.conferenceagendas = conferenceagendas;
        values.conferencenums = conferencenums;
        values.meetingdays = (new Date(container.find('[name="enddate"]').val()).getTime() - new Date(container.find('[name="startdate"]').val()).getTime()) / (1000 * 60 * 60 * 24) + 1;
        values.sprReportId = taskData ? taskData.sprReportId : '';
        values.sprPlanDetailId = taskData ? taskData.sprPlanDetailId : '';
        // app端
        values.isApp = true;
        var param = {
            ajaxUrl: 'api/services/app/sponsorshipconference/CreateOrUpdateSponsorship',
            ajaxMethod: 'post',
            ajaxValues: values,
            ajaxCallback: saveDataCallback,
            ajaxAgainEvt: saveData,
            ajaxText: '新增赞助学术会议'
        }
        common.ajaxMethod(param);
    }
    function saveDataCallback(ret) {
        navbarInnerContainer.find('.btn-submit').removeClass('disabled');
        if (ret.result.status == 'y') {
            common.notification('恭喜', '添加成功', 'success');
            // 更新列表数据页面
            $$(document).trigger('after-list-update');
            var currentView = app.getCurrentView();
            currentView.router.back();
        } else {
            //弹出提示,这里比较特殊返回信息里有是否是Y的判断,这里单独判断下
            app.modal({
                title: '操作失败',
                text: '<i class="icon icon-error"></i>' + '<p class="decription">' + ret.result.msg + '</p>',
                buttons: [{
                    text: '知道了'
                }]
            });
        }
    }
});